@@ -1,19 +1,7 @@
-/* This file is part of Step.
-   Copyright (C) 2007 Vladimir Kuznetsov <ks.vladimir@gmail.com>
+/*.
+    SPDX-FileCopyrightText: 2007 Vladimir Kuznetsov <ks.vladimir@gmail.com>
 
-   Step is free software; you can redistribute it and/or modify
-   it under the terms of the GNU General Public License as published by
-   the Free Software Foundation; either version 2 of the License, or
-   (at your option) any later version.
-
-   Step is distributed in the hope that it will be useful,
-   but WITHOUT ANY WARRANTY; without even the implied warranty of
-   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-   GNU General Public License for more details.
-
-   You should have received a copy of the GNU General Public License
-   along with Step; if not, write to the Free Software
-   Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
+    SPDX-License-Identifier: GPL-2.0-or-later
 */
 
 #ifndef STEP_WORLDSCENE_H
@@ -63,7 +51,7 @@ public:
     Q_DECLARE_FLAGS(SnapFlags, SnapFlag)
 
     /** Construct WorldScene */
-    explicit WorldScene(WorldModel* worldModel, QObject* parent = 0);
+    explicit WorldScene(WorldModel* worldModel, QObject* parent = nullptr);
     ~WorldScene();
 
     /** Get StepCore::Item by QGraphicsItem */
@@ -84,7 +72,7 @@ public:
      *  \param pos position
      *  \param flags snap flags
      *  \param moreTypes additional item types to snap */
-    StepCore::Item* snapHighlight(QPointF pos, SnapFlags flags, const SnapList* moreTypes = 0);
+    StepCore::Item* snapHighlight(QPointF pos, SnapFlags flags, const SnapList* moreTypes = nullptr);
 
     /** Remove highlighting */
     void snapClear();
